package com.sun.jmx.snmp;

import java.util.Hashtable;
import java.io.Serializable;

public class EnumRowStatus extends Enumerated implements Serializable
{
    private static final long serialVersionUID = 8966519271130162420L;
    public static final int unspecified = 0;
    public static final int active = 1;
    public static final int notInService = 2;
    public static final int notReady = 3;
    public static final int createAndGo = 4;
    public static final int createAndWait = 5;
    public static final int destroy = 6;
    static final Hashtable<Integer, String> intTable;
    static final Hashtable<String, Integer> stringTable;
    
    public EnumRowStatus(int n) throws IllegalArgumentException {
        super(n);
    }
    
    public EnumRowStatus(Enumerated enumerated) throws IllegalArgumentException {
        this(enumerated.intValue());
    }
    
    public EnumRowStatus(long n) throws IllegalArgumentException {
        this((int)n);
    }
    
    public EnumRowStatus(Integer n) throws IllegalArgumentException {
        super(n);
    }
    
    public EnumRowStatus(Long n) throws IllegalArgumentException {
        this((long)n);
    }
    
    public EnumRowStatus() throws IllegalArgumentException {
        this(0);
    }
    
    public EnumRowStatus(String s) throws IllegalArgumentException {
        super(s);
    }
    
    public EnumRowStatus(SnmpInt snmpInt) throws IllegalArgumentException {
        this(snmpInt.intValue());
    }
    
    public SnmpInt toSnmpValue() throws IllegalArgumentException {
        if (this.value == 0) {
            throw new IllegalArgumentException("`unspecified' is not a valid SNMP value.");
        }
        return new SnmpInt(this.value);
    }
    
    public static boolean isValidValue(int n) {
        return n >= 0 && n <= 6;
    }
    
    @Override
    protected Hashtable<Integer, String> getIntTable() {
        return getRSIntTable();
    }
    
    @Override
    protected Hashtable<String, Integer> getStringTable() {
        return getRSStringTable();
    }
    
    static Hashtable<Integer, String> getRSIntTable() {
        return EnumRowStatus.intTable;
    }
    
    static Hashtable<String, Integer> getRSStringTable() {
        return EnumRowStatus.stringTable;
    }
    
    static {
        intTable = new Hashtable();
        stringTable = new Hashtable();
        EnumRowStatus.intTable.put(new Integer(0), "unspecified");
        EnumRowStatus.intTable.put(new Integer(3), "notReady");
        EnumRowStatus.intTable.put(new Integer(6), "destroy");
        EnumRowStatus.intTable.put(new Integer(2), "notInService");
        EnumRowStatus.intTable.put(new Integer(5), "createAndWait");
        EnumRowStatus.intTable.put(new Integer(1), "active");
        EnumRowStatus.intTable.put(new Integer(4), "createAndGo");
        EnumRowStatus.stringTable.put("unspecified", new Integer(0));
        EnumRowStatus.stringTable.put("notReady", new Integer(3));
        EnumRowStatus.stringTable.put("destroy", new Integer(6));
        EnumRowStatus.stringTable.put("notInService", new Integer(2));
        EnumRowStatus.stringTable.put("createAndWait", new Integer(5));
        EnumRowStatus.stringTable.put("active", new Integer(1));
        EnumRowStatus.stringTable.put("createAndGo", new Integer(4));
    }
}
